@@ -4,5 +4,6 @@ test_that("get_solution() inputs are checked", {
 })
 
 test_that("get_solution() works", {
-  expect_snapshot(get_solution(orbital_solution = "ZB18a") |> head())
+  withr::local_options(width = 150)
+  expect_snapshot(get_solution(orbital_solution = "ZB18a", quiet = TRUE) |> head())
 })
